@@ -162,8 +162,8 @@ class logged_in:
    
     ''' This function initialises both the Http server Pusher as well as the clientPusher'''
     def initPusher(self):
-        self.pusher = Pusher(app_id=os.getenv('PUSHER_APP_ID', None), key=os.getenv('PUSHER_APP_KEY', None), secret=os.getenv('PUSHER_APP_SECRET', None), cluster=os.getenv('PUSHER_APP_CLUSTER', None))
-        self.clientPusher = pysher.Pusher(os.getenv('PUSHER_APP_KEY', None), os.getenv('PUSHER_APP_CLUSTER', None))
+        self.pusher = Pusher(app_id=os.getenv('PUSHER_APP_ID', '1006082'), key=os.getenv('PUSHER_APP_KEY', 'e609aeea48c0c31e5fb1'), secret=os.getenv('PUSHER_APP_SECRET', '93b8e77f996839a42523'), cluster=os.getenv('PUSHER_APP_CLUSTER', 'eu'))
+        self.clientPusher = pysher.Pusher(os.getenv('PUSHER_APP_KEY', 'e609aeea48c0c31e5fb1'), os.getenv('PUSHER_APP_CLUSTER', 'eu'))
         self.clientPusher.connection.bind('pusher:connection_established', self.connectHandler)
         self.clientPusher.connect()
         
